@@ -368,8 +368,13 @@ class TUI:
                 telemetry_name == TelemetryName.WATER_TEMP_C_TIMES1000
                 or telemetry_name == TelemetryName.WATER_TEMP_C_TIMES1000.value
             ):
-                value_str = f"{snap.Snapshot.ValueList[i]/1000:5.2f}"
-                unit = "C"
+                centigrade = snap.Snapshot.ValueList[i] / 1000
+                if self.settings.tui.c_to_f:
+                    value_str = f"{(centigrade * 9/5) + 32:5.2f}"
+                    unit = "F"
+                else:
+                    value_str = f"{centigrade:5.2f}"
+                    unit = "C"
             elif (
                 telemetry_name == TelemetryName.WATER_TEMP_F_TIMES1000
                 or telemetry_name == TelemetryName.WATER_TEMP_F_TIMES1000.value
